Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type After ¶
type After struct {
Name string `hcl:"func,label"`
}
After is a block to check the specified function is called after the function of parent block is called.
type Before ¶
Before is a block to check the specified function is called before the function of parent block is called.
type Config ¶
type Config struct {
Rules []Rule `hcl:"rule,block"`
}
Config has a slice of rule that defines the analyzer.
type Func ¶
type Func struct {
Name string `hcl:"name,label"`
Receiver *string `hcl:"receiver,optional"`
Befores []Before `hcl:"before,block"`
Afters []After `hcl:"after,block"`
}
Func is a block to check the function including method is properly used.
Click to show internal directories.
Click to hide internal directories.